@@ -3,11 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0300';
 
 use strict;
 use warnings;
 
+use MIDI::Track;
 use MIDI::Simple;
 use Music::Tempo;
 
@@ -39,6 +40,23 @@ sub setup_score {
 }
 
 
+sub new_track {
+    my %args = (
+        channel => 0,
+        patch   => 0,
+        tempo   => 500000,
+        @_,
+    );
+
+    my $track = MIDI::Track->new;
+
+    $track->new_event( 'set_tempo', 0, $args{tempo} );
+    $track->new_event( 'patch_change', 0, $args{channel}, $args{patch} );
+
+    return $track;
+}
+
+
 sub set_chan_patch {
     my ( $score, $channel, $patch ) = @_;
 
@@ -64,15 +82,18 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
   use MIDI::Util;
+
   my $score = MIDI::Util::setup_score( bpm => 120, etc => '...', );
-  # ...
+
   MIDI::Util::set_chan_patch( $score, 0, 1 );
 
+  my $track = MIDI::Util::new_track( channel => 0, patch => 1, tempo => 450_000 );
+
 =head1 DESCRIPTION
 
 C<MIDI::Util> comprises a couple handy MIDI utilities.
@@ -90,7 +111,7 @@ C<MIDI::Util> comprises a couple handy MIDI utilities.
     octave  => 4,
   );
 
-Set basic MIDI parameters and return a L<MIDI::Simple> score object.  If given a
+Set basic MIDI parameters and return a L<MIDI::Simple> object.  If given a
 B<lead_in>, play a hi-hat for that many beats.
 
 Named parameters and defaults:
@@ -102,6 +123,18 @@ Named parameters and defaults:
   patch:   0
   octave:  4
 
+=head2 new_track()
+
+  $track = MIDI::Util::new_track(%arguments);
+
+Set the B<channel>, B<patch>, and B<tempo> and return a L<MIDI::Track> object.
+
+Named parameters and defaults:
+
+  channel: 0
+  patch:   0
+  tempo:   500000
+
 =head2 set_chan_patch()
 
   MIDI::Util::set_chan_patch( $score, $channel, $patch );
